==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Text/Text.view.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var Text = function (_StatelessComponent) {
  _inherits(Text, _StatelessComponent);

  var _super = _createSuper(Text);

  function Text() {
    _classCallCheck(this, Text);

    return _super.apply(this, arguments);
  }

  _createClass(Text, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          styles = _context$props.styles,
          block = _context$props.block,
          nowrap = _context$props.nowrap,
          variant = _context$props.variant;
      var classNames = getClassNames(styles, {
        theme: theme,
        block: block,
        nowrap: nowrap,
        variant: variant
      });
      return h("span", _mergeJSXProps([{}, context.data, {
        "class": classNames.root
      }]), [context.children]);
    }
  }]);

  return Text;
}(StatelessComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], Text.prototype, "nowrap", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], Text.prototype, "block", void 0);

__decorate([Prop({
  type: String,
  "default": 'medium'
}), __metadata("design:type", String)], Text.prototype, "variant", void 0);

Text = __decorate([Component], Text);
var TextView = Text;

export default TextView;

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Text/Text.view.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var Text = function (_StatelessComponent) {
  _inherits(Text, _StatelessComponent);

  var _super = _createSuper(Text);

  function Text() {
    _classCallCheck(this, Text);

    return _super.apply(this, arguments);
  }

  _createClass(Text, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          styles = _context$props.styles,
          block = _context$props.block,
          nowrap = _context$props.nowrap,
          variant = _context$props.variant;
      var classNames = getClassNames(styles, {
        theme: theme,
        block: block,
        nowrap: nowrap,
        variant: variant
      });
      return h("span", _mergeJSXProps([{}, context.data, {
        "class": classNames.root
      }]), [context.children]);
    }
  }]);

  return Text;
}(StatelessComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], Text.prototype, "nowrap", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], Text.prototype, "block", void 0);

__decorate([Prop({
  type: String,
  default: 'medium'
}), __metadata("design:type", String)], Text.prototype, "variant", void 0);

Text = __decorate([Component], Text);
var TextView = Text;

export default TextView;
